@@ -12,7 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 """
  This package provides a client library for accessing the IBM Cloud Platform Services.
 """
@@ -25,6 +24,7 @@ from .version import __version__
 from .case_management_v1 import CaseManagementV1
 from .catalog_management_v1 import CatalogManagementV1
 from .configuration_governance_v1 import ConfigurationGovernanceV1
+from .enterprise_billing_units_v1 import EnterpriseBillingUnitsV1
 from .enterprise_management_v1 import EnterpriseManagementV1
 from .enterprise_usage_reports_v1 import EnterpriseUsageReportsV1
 from .global_catalog_v1 import GlobalCatalogV1
@@ -36,5 +36,6 @@ from .iam_policy_management_v1 import IamPolicyManagementV1
 from .open_service_broker_v1 import OpenServiceBrokerV1
 from .resource_controller_v2 import ResourceControllerV2
 from .resource_manager_v2 import ResourceManagerV2
+from .usage_metering_v4 import UsageMeteringV4
 from .usage_reports_v4 import UsageReportsV4
 from .user_management_v1 import UserManagementV1
